summaryrefslogtreecommitdiffstats
path: root/korn/maildlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/maildlg.h')
-rw-r--r--korn/maildlg.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/korn/maildlg.h b/korn/maildlg.h
index c8ba216a..68f8f30e 100644
--- a/korn/maildlg.h
+++ b/korn/maildlg.h
@@ -17,6 +17,7 @@ class TQString;
class KornMailDlg : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
/**
* Edit control showing the mail (read only)
@@ -45,9 +46,9 @@ class KornMailDlg : public KDialogBase
public:
/**
* KornMailDlg Constructor
* @param parent parent widget
*/
- KornMailDlg( TQWidget *parent=0 );
+ KornMailDlg( TQWidget *tqparent=0 );
/**
* Set the mail details to show. The mails body is transfered to the edit control
@@ -45,9 +46,9 @@ class KornMailDlg : public KDialogBase
/**
* KornMailDlg Constructor
- * @param parent parent widget
+ * @param tqparent tqparent widget
*/